"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeEmissionDistributorIx = exports.distributeEmissionsIx = exports.manualMintIx = exports.updateEmissionScheduleIx = void 0;
const index_1 = require("./index");
const bn_js_1 = __importDefault(require("bn.js"));
const spl_utils_1 = require("@render-foundation/spl-utils");
const updateEmissionScheduleIx = (program, rndrMint, args, accts) => {
    var _a;
    return program
        .methods
        .updateEmissionScheduleV0({
        emissionSchedule: (_a = args.emissionSchedule) === null || _a === void 0 ? void 0 : _a.map(({ startUnixTime, emissionsPerEpoch }) => ({
            startUnixTime: new bn_js_1.default(startUnixTime),
            emissionsPerEpoch: new bn_js_1.default(emissionsPerEpoch)
        })),
        epochDurationSecs: args.epochDurationSecs ? new bn_js_1.default(args.epochDurationSecs) : null
    })
        .accounts({
        authority: accts.authority,
        schedule: (0, index_1.emissionScheduleKey)(rndrMint)[0]
    }).instruction();
};
exports.updateEmissionScheduleIx = updateEmissionScheduleIx;
const manualMintIx = (program, rndrMint, recipientAta, authority, amount) => {
    return program.methods.manualMintV0({ amount: new bn_js_1.default(amount) })
        .accounts({
        //circuitBreaker: circuitBreakerK,
        //payer: authority,
        authority,
        recipientAta,
        rndrMint: rndrMint,
        emissionDistributor: (0, index_1.emissionDistributorKey)(rndrMint)[0]
    }).instruction();
};
exports.manualMintIx = manualMintIx;
const distributeEmissionsIx = (program, rndrMint, escrows) => {
    return program.methods
        .distributeEmissionsV0()
        .accounts({
        emissionDistributor: (0, index_1.emissionDistributorKey)(rndrMint)[0],
        emissionSchedule: (0, index_1.emissionScheduleKey)(rndrMint)[0],
        rndrMint: rndrMint
    })
        .remainingAccounts(escrows.map((a) => ({ pubkey: a, isSigner: false, isWritable: true })))
        .instruction();
};
exports.distributeEmissionsIx = distributeEmissionsIx;
const initializeEmissionDistributorIx = (program, rndrMint, args) => {
    var _a, _b;
    return program
        .methods
        .initializeEmissionDistributorV0({
        authority: args.authority,
        manualEmissionAuthority: (_a = args.manualEmissionAuthority) !== null && _a !== void 0 ? _a : args.authority,
        distributionAccounts: args.distributionAccounts,
        epochDurationSec: new bn_js_1.default(args.epochDurationSec),
        emissionSchedule: args.schedule.map(i => ({ startUnixTime: new bn_js_1.default(i.startUnixTime),
            emissionsPerEpoch: (0, spl_utils_1.toBN)(i.emissionsPerEpoch, rndrMint.decimals) })),
        mintCircuitBreakerConfig: args.mintCircuitBreakerConfig,
        currentEpochBeganAt: new bn_js_1.default(args.currentEpochBeganAt)
    }).
        accounts({
        payer: (_b = args.payer) !== null && _b !== void 0 ? _b : rndrMint.mintAuthority,
        mintAuthority: rndrMint.mintAuthority,
        freezeAuthority: rndrMint.freezeAuthority,
        //circuitBreaker: mintWindowedBreakerKey(rndrMint.address)[0],
        emissionDistributor: (0, index_1.emissionDistributorKey)(rndrMint.address)[0],
        emissionSchedule: (0, index_1.emissionScheduleKey)(rndrMint.address)[0],
        rndrMint: rndrMint.address,
    }).instruction();
};
exports.initializeEmissionDistributorIx = initializeEmissionDistributorIx;
//# sourceMappingURL=instructions.js.map