import { emissionDistributorKey, emissionScheduleKey } from "./index";
import BN from "bn.js";
import { toBN } from "@render-foundation/spl-utils";
export const updateEmissionScheduleIx = (program, rndrMint, args, accts) => {
    return program
        .methods
        .updateEmissionScheduleV0({
        emissionSchedule: args.emissionSchedule?.map(({ startUnixTime, emissionsPerEpoch }) => ({
            startUnixTime: new BN(startUnixTime),
            emissionsPerEpoch: new BN(emissionsPerEpoch)
        })),
        epochDurationSecs: args.epochDurationSecs ? new BN(args.epochDurationSecs) : null
    })
        .accounts({
        authority: accts.authority,
        schedule: emissionScheduleKey(rndrMint)[0]
    }).instruction();
};
export const manualMintIx = (program, rndrMint, recipientAta, authority, amount) => {
    return program.methods.manualMintV0({ amount: new BN(amount) })
        .accounts({
        //circuitBreaker: circuitBreakerK,
        //payer: authority,
        authority,
        recipientAta,
        rndrMint: rndrMint,
        emissionDistributor: emissionDistributorKey(rndrMint)[0]
    }).instruction();
};
export const distributeEmissionsIx = (program, rndrMint, escrows) => {
    return program.methods
        .distributeEmissionsV0()
        .accounts({
        emissionDistributor: emissionDistributorKey(rndrMint)[0],
        emissionSchedule: emissionScheduleKey(rndrMint)[0],
        rndrMint: rndrMint
    })
        .remainingAccounts(escrows.map((a) => ({ pubkey: a, isSigner: false, isWritable: true })))
        .instruction();
};
export const initializeEmissionDistributorIx = (program, rndrMint, args) => {
    return program
        .methods
        .initializeEmissionDistributorV0({
        authority: args.authority,
        manualEmissionAuthority: args.manualEmissionAuthority ?? args.authority,
        distributionAccounts: args.distributionAccounts,
        epochDurationSec: new BN(args.epochDurationSec),
        emissionSchedule: args.schedule.map(i => ({ startUnixTime: new BN(i.startUnixTime),
            emissionsPerEpoch: toBN(i.emissionsPerEpoch, rndrMint.decimals) })),
        mintCircuitBreakerConfig: args.mintCircuitBreakerConfig,
        currentEpochBeganAt: new BN(args.currentEpochBeganAt)
    }).
        accounts({
        payer: args.payer ?? rndrMint.mintAuthority,
        mintAuthority: rndrMint.mintAuthority,
        freezeAuthority: rndrMint.freezeAuthority,
        //circuitBreaker: mintWindowedBreakerKey(rndrMint.address)[0],
        emissionDistributor: emissionDistributorKey(rndrMint.address)[0],
        emissionSchedule: emissionScheduleKey(rndrMint.address)[0],
        rndrMint: rndrMint.address,
    }).instruction();
};
//# sourceMappingURL=instructions.js.map